@@ -15,6 +15,7 @@
 #' @param pval logical: add the pvalue to the plot?
 #' @param pval.size numeric value specifying the p-value text size. Default is 5.
 #' @param pval.coord numeric vector, of length 2, specifying the x and y coordinates of the p-value. Default values are NULL
+#' @param pval.testname logical: add '(Log-rank)' text to p-value. Default = F
 #' @param marks logical: should censoring marks be added?
 #' @param shape what shape should the censoring marks be, default is a vertical line
 #' @param legend logical. should a legend be added to the plot?
@@ -88,6 +89,7 @@ jskm <- function(sfit,
                  pval = FALSE,
                  pval.size = 5, 
                  pval.coord = c(NULL, NULL),
+                 pval.testname = F,
                  marks = TRUE,
                  shape = 3,
                  legend = TRUE,
@@ -292,7 +294,10 @@ jskm <- function(sfit,
       pvalue <- summary(sdiff)$logtest["pvalue"]
     }
     
-    pvaltxt <- ifelse(pvalue < 0.0001,"p < 0.0001",paste("p =", signif(pvalue, 3)))
+    pvaltxt <- ifelse(pvalue < 0.0001,"p < 0.0001",paste("p =", round(pvalue, 3)))
+    
+    if (pval.testname) pvaltxt <- paste0(pvaltxt, " (Log-rank)")
+    
     # MOVE P-VALUE LEGEND HERE BELOW [set x and y]
     if (is.null(pval.coord)){
       p <- p + annotate("text",x = (as.integer(max(sfit$time)/5)), y = 0.1 + ylims[1],label = pvaltxt, size  = pval.size)
